from django.db import models
from django.utils import timezone


class CommonFields(models.Model):
    added_on = models.DateTimeField(null=True, auto_now_add=True)
    updated_on = models.DateTimeField(null=True, auto_now_add=True)

    class Meta:
        abstract = True


class Permalinks(CommonFields):
    permalink_id = models.BigAutoField(primary_key=True)
    old_url = models.URLField(max_length=300, verbose_name="Old URL", unique=True,
                              help_text="This is the URL that will be redirected.<br>Follow Full URL Scheme: <b>https://www.example.com/myapp/mypage.html</b>")
    new_url = models.URLField(max_length=300, verbose_name="New URL",
                              help_text="This is the URL to which the above URL will be redirected.<br>Follow Full URL Scheme: <b>https://www.example.com/myapp/mypage.html</b>")

    def __str__(self):
        return self.old_url

    def save(self, *args, **kwargs):
        self.updated_on = timezone.now()
        super(Permalinks, self).save(*args, **kwargs)

    class Meta:
        verbose_name = 'Permalink'
        verbose_name_plural = 'Permalinks'


from django.contrib import admin
from django.utils.html import format_html

from .models import Permalinks


class PermalinksAdmin(admin.ModelAdmin):
    """Admin options for Permalinks"""

    fieldsets = [
        ('URL Redirects', {
            'fields': [
                'old_url',
                'new_url',
            ],
        }),
    ]

    list_display = (
        'old_url',
        'new_url',
    )

    search_fields = [
        'old_url',
        'new_url',
    ]


admin.site.register(Permalinks, PermalinksAdmin)


from permalinks.models import Permalinks
from django.http import HttpResponseRedirect

class PermalinksMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response
        # One-time configuration and initialization.

    def __call__(self, request):
        # Code to be executed for each request before
        # the view (and later middleware) are called.

        response = self.get_response(request)
        try:
          old_url_object = Permalinks.objects.get(old_url=request.build_absolute_uri())
          return HttpResponseRedirect(old_url_object.new_url)
        except Exception as e:
          return response


import setuptools
import os

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

with open("README.md", "r") as fh:
    long_description = fh.read()

install_requirements = [
    "django>=1.8",
]

setuptools.setup(
    name="django-permalinks",
    version="0.0.2",
    install_requires=install_requirements,
    license='MIT License',
    author="Aekansh Dixit",
    author_email="aekanshdixit@gmail.com",
    description="A Django App to make sure old URLs work with new URLs.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/aekanshd/django-permalinks",
    packages=setuptools.find_packages(),
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 1.8",
        "Framework :: Django :: 1.9",
        "Framework :: Django :: 1.10",
        "Framework :: Django :: 1.11",
        "Framework :: Django :: 2.0",
        "Framework :: Django :: 2.1",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
)



# Generated by Django 2.2.4 on 2019-08-16 17:10

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Permalinks',
            fields=[
                ('added_on', models.DateTimeField(auto_now_add=True, null=True)),
                ('updated_on', models.DateTimeField(auto_now_add=True, null=True)),
                ('permalink_id', models.BigAutoField(primary_key=True, serialize=False)),
                ('old_url', models.URLField(help_text='This is the URL that will be redirected.<br>Follow Full URL Scheme: <b>https://www.example.com/myapp/mypage.html</b>', max_length=300, verbose_name='Old URL')),
                ('new_url', models.URLField(help_text='This is the URL to which the above URL will be redirected.<br>Follow Full URL Scheme: <b>https://www.example.com/myapp/mypage.html</b>', max_length=300, verbose_name='New URL')),
            ],
            options={
                'verbose_name': 'Permalink',
                'verbose_name_plural': 'Permalinks',
            },
        ),
    ]
